@@ -1,14 +1,20 @@
 import logging
+from datetime import datetime
+from enum import Enum
 from pathlib import Path
-from typing import Optional
+from shutil import copy
+from string import ascii_letters
+from typing import Optional, Dict
 
 import asyncclick as click
+import pandas as pd
 from playwright.async_api import (
     async_playwright,
     Error,
     TimeoutError as PlayWrightTimeout,
 )
 from rich import print
+from rich.console import Console
 from rich.prompt import Prompt
 from rich.traceback import install
 
@@ -26,6 +32,7 @@ from playwrighting.exceptions import (
     StateFileAlreadyExists,
     NotAValidChoice,
     ParentDirectoryDoesNotExist,
+    StateFileDoesNotExist,
 )
 from playwrighting.navigation.login import login
 
@@ -129,31 +136,89 @@ async def download(download_path: Optional[str], create_parents: bool):
             )
 
 
+class ShowOptions(str, Enum):
+    position: str = "position"
+    account: str = "accounts"
+    transactions: str = "transactions"
+
+
+def get_account_or_card_selection_choices(
+    position: Position,
+) -> Dict[str, pd.DataFrame]:
+    cards_choices = {
+        f"{i + 1}.{ascii_letters[j]}": account.transactions
+        for i, account in enumerate(position.accounts)
+        for j, _ in enumerate(account.cards)
+    }
+    accounts_choices = {
+        f"{i + 1}": account.transactions for i, account in enumerate(position.accounts)
+    }
+
+    return cards_choices | accounts_choices
+
+
 @click.command()
 @click.option("--option", default=None)
 async def show(option):
-    # TODO move to enum
-    options = ["position", "accounts", "cards"]
     if not option:
         option = Prompt.ask(
-            "What do you want to show?", choices=options, default="position"
+            "What do you want to show?",
+            choices=list(ShowOptions),
+            default=ShowOptions.position,
         )
     else:
-        if option not in options:
+        if option not in list(ShowOptions):
             raise NotAValidChoice("Selected option is not a valid choice")
 
     position = Position.load()
 
-    # TODO create repr and str of all classes
-
     if position:
         if option == "position":
-            print(position)
+            print(str(position))
         elif option == "accounts":
-            print(position.accounts)
-        elif option == "cards":
-            for account in position.accounts:
-                print(account.cards)
+            message = f"""Accounts:
+        {"".join([f"{i + 1}) {account.position()}" for i, account in enumerate(position.accounts)])}
+        """
+            print(message)
+        elif option == "transactions":
+            cards_lines = "".join(
+                [
+                    f"{i + 1}) {account.transactions_menu(i + 1)}"
+                    for i, account in enumerate(position.accounts)
+                ]
+            )
+            message = f"""Choose an account or card:
+        {cards_lines}
+        """
+
+            account_or_card_selection_choices = get_account_or_card_selection_choices(
+                position
+            )
+            account_or_card_selection = Prompt.ask(
+                message,
+                choices=list(account_or_card_selection_choices.keys()),
+                default=list(account_or_card_selection_choices.keys())[0],
+            )
+
+            console = Console()
+            with console.pager():
+                console.print(
+                    account_or_card_selection_choices[account_or_card_selection]
+                )
+
+
+@click.command()
+@click.option("--destiny_name", default=None, help="destiny backup file name")
+async def backup(destiny_name: str):
+    origin_state = app_path / STATE_FILE_NAME
+    now = datetime.now().strftime("%d%b%y-%H%M")
+    destiny_file_name = f"{destiny_name or now}.pkl"
+    destiny_state = app_path / destiny_file_name
+
+    if not origin_state.exists():
+        raise StateFileDoesNotExist("Cannot backup because state file doesn't exist")
+
+    copy(origin_state, destiny_state)
 
 
 install()
@@ -161,6 +226,7 @@ cli.add_command(init)
 cli.add_command(update)
 cli.add_command(download)
 cli.add_command(show)
+cli.add_command(backup)
 
 if __name__ == "__main__":
     cli(_anyio_backend="asyncio")
